@@ -5,9 +5,9 @@ from PyQt5.QtWidgets import (QVBoxLayout, QHBoxLayout, QLabel, QTextEdit, QWidge
         QComboBox, QCheckBox, QGridLayout, QSpacerItem, QLineEdit, QPushButton)
 from PyQt5.QtCore import QCoreApplication as QC
 import logging
-from elementeditor import ElementEditor
-from record_function import Record, Function
-from elementmaster import alphabet
+from Pythonic.elementeditor import ElementEditor
+from Pythonic.record_function import Record, Function
+from Pythonic.elementmaster import alphabet
 
 
 class ExecBranch(ElementMaster):
